@@ -18,16 +18,18 @@ class WebhookVerificationError(Exception):
 class Webhook:
     _SECRET_PREFIX: str = "whsec_"
     _whsecret: bytes
-    _enc_key: t.Optional[bytes]
 
-    def __init__(self, whsecret: str, *, enc_key: t.Optional[str] = None):
+    def __init__(self, whsecret: t.Union[str, bytes]):
         if not whsecret:
             raise RuntimeError("Secret can't be empty.")
 
-        if whsecret.startswith(self._SECRET_PREFIX):
-            whsecret = whsecret[len(self._SECRET_PREFIX) :]
-        self._whsecret = base64.b64decode(whsecret)
-        self._enc_key = base64.b64decode(enc_key) if enc_key is not None else None
+        if isinstance(whsecret, str):
+            if whsecret.startswith(self._SECRET_PREFIX):
+                whsecret = whsecret[len(self._SECRET_PREFIX) :]
+            self._whsecret = base64.b64decode(whsecret)
+
+        if isinstance(whsecret, bytes):
+            self._whsecret = whsecret
 
     def verify(self, data: t.Union[bytes, str], headers: t.Dict[str, str]) -> t.Any:
         data = data if isinstance(data, str) else data.decode()
@@ -44,7 +46,9 @@ class Webhook:
 
         timestamp = self.__verify_timestamp(msg_timestamp)
 
-        expected_sig = base64.b64decode(self.sign(msg_id=msg_id, timestamp=timestamp, data=data).split(",")[1])
+        expected_sig = base64.b64decode(
+            self.sign(msg_id=msg_id, timestamp=timestamp, data=data).split(",")[1]
+        )
         passed_sigs = msg_signature.split(" ")
         for versioned_sig in passed_sigs:
             (version, signature) = versioned_sig.split(",")
